==> uberfire-parent-7.46.0.Final-project-sources.tar.gz: uberfire-parent-7.46.0.Final/uberfire-extensions/uberfire-commons-editor/uberfire-commons-editor-client/src/test/java/org/uberfire/ext/editor/commons/client/file/exports/ImageFileExportTest.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.uberfire.ext.editor.commons.client.file.exports;

import com.google.gwtmockito.GwtMockitoTestRunner;
import org.jboss.errai.common.client.dom.Blob;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import static org.junit.Assert.assertEquals;
import static org.mockito.Matchers.eq;
import static org.mockito.Mockito.any;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;

@RunWith(GwtMockitoTestRunner.class)
public class ImageFileExportTest extends AbstractFileExportTest {

    private ImageFileExport tested;

    @Before
    public void setup() {
        tested = new ImageFileExport(fileSaver);
    }

    @Test
    public void testExport() {
        ImageDataUriContent imageContent = ImageDataUriContent.create("data:image/jpeg;base64,9j/4AAQSkZJRgABAQEASABIAAD");
        assertEquals("data:image/jpeg;base64,9j/4AAQSkZJRgABAQEASABIAAD",
                     imageContent.getUri());
        assertEquals("image/jpeg",
                     imageContent.getMimeType());
        assertEquals("9j/4AAQSkZJRgABAQEASABIAAD",
                     imageContent.getData());
        tested.export(imageContent,
                      FILE_NAME);
        verify(fileSaver,
               times(1)).accept(any(Blob.class),
                                eq(FILE_NAME));
    }
}

==> uberfire-parent-7.62.0.Final-project-sources.tar.gz: uberfire-parent-7.62.0.Final/uberfire-extensions/uberfire-commons-editor/uberfire-commons-editor-client/src/test/java/org/uberfire/ext/editor/commons/client/file/exports/ImageFileExportTest.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.uberfire.ext.editor.commons.client.file.exports;

import com.google.gwtmockito.GwtMockitoTestRunner;
import org.jboss.errai.common.client.dom.Blob;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import static org.junit.Assert.assertEquals;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.any;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;

@RunWith(GwtMockitoTestRunner.class)
public class ImageFileExportTest extends AbstractFileExportTest {

    private ImageFileExport tested;

    @Before
    public void setup() {
        tested = new ImageFileExport(fileSaver);
    }

    @Test
    public void testExport() {
        ImageDataUriContent imageContent = ImageDataUriContent.create("data:image/jpeg;base64,9j/4AAQSkZJRgABAQEASABIAAD");
        assertEquals("data:image/jpeg;base64,9j/4AAQSkZJRgABAQEASABIAAD",
                     imageContent.getUri());
        assertEquals("image/jpeg",
                     imageContent.getMimeType());
        assertEquals("9j/4AAQSkZJRgABAQEASABIAAD",
                     imageContent.getData());
        tested.export(imageContent,
                      FILE_NAME);
        verify(fileSaver,
               times(1)).accept(any(Blob.class),
                                eq(FILE_NAME));
    }
}
